%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This is a example for the prediction of the flux distribution of pyk    %
% mutant of E. coli by Enzyme Control Flux                                %
%                                                                         %
% Corresponding author: Prof. Hiroyuki Kurata                             %
% kurata@bio.kyutech.ac.jp                                                %
% Kyushu Institute of Technology, Iizuka, Fukuoka, Japan                  %
% 2008.09                                                                 %  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% EmMatrix is the elementary mode matrix; reactions*EMs
% ramdaMatrix is elementary mode coefficients vector; EMs*(2*EMs)
% ns is the No. of substrate uptake reaction
% sflux is the flux of substrate uptake
% enzyme is the relative enzyme activity ratio of mutant versus wild type

load ecfexample.mat
[n_reaction,n_EM]=size(EmMatrix);
% n_reaction is the total number of reactions
% n_EM is the total number of Elementary Modes
pls=ones(n_EM,1); % pls is for the power law equation of enzyme activity
plambta=ones(n_EM,n_EM*2); 

for j=1:n_EM
    for i=1:n_reaction
        if EmMatrix(i,j)~=0.0
        pls(j,1)=enzyme(1,i)*pls(j,1);
        end
    end
    plambta(j,:)=pls(j,1)*ramdaMatrix(j,:);
end

for i=1:1:2*n_EM
gama(i,1)=sflux/(EmMatrix(ns,:)*plambta(:,i));
% gama is a parameter for the normalization of fluxes

fluxcalu(:,i)=EmMatrix*plambta(:,i)*gama(i,1);
end

fluxmean=mean(fluxcalu')';
disp('the flux distribution of pyk mutant of E. coli is:')
disp(' ')
disp(fluxmean)
save fluxresult.mat fluxcalu fluxmean